@@ -822,7 +822,7 @@ Lire::DlfConverter(3pm)
 
 =head1 VERSION
 
-$Id: DlfStore.pm,v 1.38 2004/10/09 18:18:59 flacoste Exp $
+$Id: DlfStore.pm,v 1.39 2006/07/23 13:16:29 vanbaal Exp $
 
 =head1 COPYRIGHT
 
@@ -842,8 +842,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html.
 
 =cut
 
