@@ -381,6 +381,11 @@ sub suite {
          [ 'value' => '$transfer-complete' ],
          '"transfer-complete" IS NOT NULL AND "transfer-complete" != 0 AND LENGTH("transfer-complete") > 0',
          [] ],
+       [ 'DlfSource',
+         'Lire::FilterExpr::DlfSource',
+         [ 'value' => 'job-2003-05-04' ],
+         'dlf_test.dlf_source = ?',
+         [ 'job-2003-05-04' ] ],
        [ 'Not_expr',
          'Lire::FilterExpr::Not',
          [ 'expr' => $eq_expr ],
