@@ -222,7 +222,7 @@ Wessel Dankers <wsl@logreport.org>
 
 =head1 VERSION
 
-$Id: IpfilterDlfConverter.pm,v 1.5 2004/07/22 13:43:46 flacoste Exp $
+$Id: IpfilterDlfConverter.pm,v 1.6 2006/07/23 13:16:35 vanbaal Exp $
 
 =head1 COPYRIGHT
 
@@ -240,8 +240,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html.
 
 =cut
 
